@@ -608,7 +608,7 @@ class DAG:
 
         Get a subdag from ``g_`` (indicates the function here) to the end of ``dag``
 
-        >>> subdag = dag['g_',:]
+        >>> subdag = dag['g_':]
         >>> print(subdag.synopsis_string())
         f -> g_ -> g
         g -> h_ -> h
@@ -616,14 +616,14 @@ class DAG:
 
         From the beginning to ``h_``
 
-        >>> print(dag[:, 'h_'].synopsis_string())
+        >>> print(dag[:'h_'].synopsis_string())
         a -> f_ -> f
         f -> g_ -> g
         g -> h_ -> h
 
         From ``g_`` to ``h_`` (both inclusive)
 
-        >>> print(dag['g_', 'h_'].synopsis_string())
+        >>> print(dag['g_':'h_'].synopsis_string())
         f -> g_ -> g
         g -> h_ -> h
 
@@ -637,12 +637,12 @@ class DAG:
         but when we ask ``dag['g', 'h_']`` instead, ``g`` being the output node of
         function node ``g_``, we only get ``g -> h_ -> h``:
 
-        >>> print(dag['g', 'h'].synopsis_string())
+        >>> print(dag['g':'h'].synopsis_string())
         g -> h_ -> h
 
         If we wanted to include ``f`` we'd have to specify it:
 
-        >>> print(dag['f', 'h'].synopsis_string())
+        >>> print(dag['f':'h'].synopsis_string())
         f -> g_ -> g
         g -> h_ -> h
 
@@ -673,20 +673,20 @@ class DAG:
         ...     t = sorted(dag.synopsis_string().split('\\n'))
         ...     print('\\n'.join(t))
 
-        >>> print_sorted_synopsis(dag[['u', 'f'], 'h'])
+        >>> print_sorted_synopsis(dag[['u', 'f']:'h'])
         f,w -> h_ -> h
         u,v -> f_ -> f
-        >>> print_sorted_synopsis(dag['u', 'h'])
+        >>> print_sorted_synopsis(dag['u':'h'])
         f,w -> h_ -> h
         u,v -> f_ -> f
-        >>> print_sorted_synopsis(dag[['u', 'f'], ['h', 'g']])
+        >>> print_sorted_synopsis(dag[['u', 'f']:['h', 'g']])
         f -> g_ -> g
         f,w -> h_ -> h
         u,v -> f_ -> f
-        >>> print_sorted_synopsis(dag[['x', 'g'], 'k'])
+        >>> print_sorted_synopsis(dag[['x', 'g']:'k'])
         g,h -> i_ -> i
         i -> k_ -> k
-        >>> print_sorted_synopsis(dag[['x', 'g'], ['l', 'k']])
+        >>> print_sorted_synopsis(dag[['x', 'g']:['l', 'k']])
         g,h -> i_ -> i
         h,x -> j_ -> j
         i -> k_ -> k
@@ -714,45 +714,83 @@ class DAG:
             parameter_merge=self.parameter_merge,
         )
 
+    # TODO: Think about adding a ``_roll_in_orphaned_nodes=False`` argument:
+    #   See https://github.com/i2mint/meshed/issues/14 for more information.
     def partial(
         self,
         *positional_dflts,
         _remove_bound_arguments=False,
-        _roll_in_orphaned_nodes=False,
+        _consider_defaulted_arguments_as_bound=False,
         **keyword_dflts,
     ):
         """Get a curried version of the DAG.
+
         Like ``functools.partial``, but returns a DAG (not just a callable) and allows
         you to remove bound arguments as well as roll in orphaned_nodes.
 
+        :param positional_dflts: Bind arguments positionally
+        :param keyword_dflts: Bind arguments through their names
+        :param _remove_bound_arguments: False -- set to True if you don't want bound
+            arguments to show up in the signature.
+        :param _consider_defaulted_arguments_as_bound: False -- set to True if
+            you want to also consider arguments that already had defaults as bound
+            (and be removed).
+        :return:
+
+        >>> def f(a, b):
+        ...     return a + b
+        >>> def g(c, d=4):
+        ...     return c * d
+        >>> def h(f, g):
+        ...     return g - f
+        >>> dag = DAG([f, g, h])
+        >>> from inspect import signature
+        >>> str(signature(dag))
+        '(c, a, b, d=4)'
+        >>> dag(3, 1, 2, 4)  # == (3 * 4) - (1 + 2) == 12 - 3 == 9
+        9
+        >>> dag(c=3, a=1, b=2, d=4)  # same as above
+        9
+
+        >>> new_dag = dag.partial(c=3)
+        >>> isinstance(new_dag, DAG)  # it's a dag (not just a partialized callable!)
+        True
+        >>> str(signature(new_dag))
+        '(a, b, *, c=3, d=4)'
+        >>> new_dag(1, 2)  # same as dag(c=3, a=1, b=2, d=4), so:
+        9
         """
-        keyword_dflts = Sig.kwargs_from_args_and_kwargs(
+
+        keyword_dflts = self.sig.kwargs_from_args_and_kwargs(
             args=positional_dflts,
             kwargs=keyword_dflts,
-            apply_defaults=False,
+            apply_defaults=_consider_defaulted_arguments_as_bound,
+            # positional_dflts and keyword_dflts usually don't cover all arguments, so:
+            allow_partial=True,
+            # we prefer to let the user know if they're trying to bind arguments
+            # that don't exist, so:
             allow_excess=False,
+            # we don't really care about kind, so:
             ignore_kind=True,
         )
-        # if positional_dflts:
-        #     raise NotImplemented("Need to map positional_dflts to keyword_defaults")
-        # TODO(mk_instance): What about other init args (cache_last_scope, ...)?
+        # TODO: mk_instance: What about other init args (cache_last_scope, ...)?
         mk_instance = type(self)
         func_nodes = partialized_funcnodes(self, **keyword_dflts)
         new_dag = mk_instance(func_nodes)
         if _remove_bound_arguments:
-            # from i2.wrapper import rm_params
             new_sig = Sig(new_dag).remove_names(list(keyword_dflts))
             new_sig(new_dag)  # Change the signature of new_dag with bound args removed
-        if _roll_in_orphaned_nodes:
-            raise NotImplementedError(f'_roll_in_orphaned_nodes=True to be implemented')
         return new_dag
 
     def process_item(self, item):
+        assert isinstance(item, slice), f'must be a slice, was: {item}'
+
+        input_names, outs = item.start, item.stop
 
         empty_slice = slice(None)
 
         def ensure_variable_list(obj):
-            if obj == empty_slice:
+            if obj is None:
                 return self.var_nodes
             if isinstance(obj, (str, Callable)):
                 return [self.get_node_matching(obj)]
@@ -761,8 +799,8 @@ class DAG:
             else:
                 raise ValidationError(f'Unrecognized variables specification: {obj}')
 
-        assert len(item) == 2, f'Only items of size 1 or 2 are supported'
-        input_names, outs = map(ensure_variable_list, item)
+        # assert len(item) == 2, f"Only items of size 1 or 2 are supported"
+        input_names, outs = map(ensure_variable_list, [input_names, outs])
         return input_names, outs
 
     def get_node_matching(self, pattern):
@@ -1038,7 +1076,7 @@ def dot_lines_of_func_nodes(func_nodes: Iterable[FuncNode], start_lines=()):
 def dot_lines_of_func_node(func_node: FuncNode):
 
     out = func_node.out
-    func_name = func_node.name
+    func_name = func_node.display_name  # func_node.name
     if out == func_name:  # though forbidden in default FuncNode validation
         func_name = '_' + func_name
 
