@@ -7,7 +7,8 @@ def test_funcnode_bind():
     Test the renaming of arguments and output of functions using FuncNode and its
     effect on DAG
     """
-    from meshed.dag import DAG, FuncNode
+    from meshed.dag import DAG
+    from meshed import FuncNode
 
     def f(a, b):
         return a + b
@@ -66,7 +67,7 @@ def test_iterize_dag():
     # or numpy.array),
     # there's several choices...
 
-    # You could use lined.Line
+    # You could use i2.Pipe
 
     from i2 import Pipe
 
@@ -78,7 +79,9 @@ def test_binding_to_a_root_node():
     """
     See: https://github.com/i2mint/meshed/issues/7
     """
-    from meshed.dag import DAG, FuncNode, ValidationError
+    from meshed.dag import DAG
+    from meshed.util import ValidationError
+    from meshed import FuncNode
 
     def f(a, b):
         return a + b
